---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: AcuteTechnologyInc

---

### Description
A clear and concise description of what the bug is.

### What release version of aqvisa-python are you using?
 - Version: 1.0.3

### What operating system (Windows, Linux,...) and version?
 - OS: [e.g. Ubuntu 22.04]

### What did you expect to see?
A clear and concise description of what you expected to happen.

### What did you see instead?
**Screenshots**
If applicable, add screenshots to help explain your problem.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

### Any additional contents?
Place any other context about the problem here.
